@@ -20,8 +20,8 @@
  */
 #include <string.h>
 
-#include <gphoto2-library.h>
-#include <gphoto2-result.h>
+#include <gphoto2/gphoto2-library.h>
+#include <gphoto2/gphoto2-result.h>
 
 #include "print.h"
 #include "core.h"
@@ -89,11 +89,9 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 	       GPContext *context)
 {
 	Camera *camera = data;
-	int	nr, result;
-	long int size;
+	int	size, nr, result;
 
 	nr = gp_filesystem_number(fs, folder, filename, context);
-
 	if(nr < 0)
 		return nr;
 
@@ -104,10 +102,10 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 		break;
 #endif
 	case GP_FILE_TYPE_NORMAL:
-		result = mdc800_getImage(camera,nr,&data,(int*)&size);
+		result = mdc800_getImage(camera,nr,&data,&size);
 		break;
 	case GP_FILE_TYPE_PREVIEW:
-		result = mdc800_getThumbnail(camera,nr,&data,(int*)&size);
+		result = mdc800_getThumbnail(camera,nr,&data,&size);
 		break;
 	default:
 		return (GP_ERROR_NOT_SUPPORTED);
@@ -115,26 +113,11 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 	if (result < 0)
 		return result;
 
-	gp_file_set_name(file,filename);
-	gp_file_set_mime_type (file, "image/jpeg");
+	gp_file_set_mime_type (file, GP_MIME_JPEG);
 	gp_file_set_data_and_size(file, data, size);
 	return (GP_OK);
 }
 
-static int
-put_file_func (CameraFilesystem *fs, const char *folder, CameraFile *file,
-	       void *data, GPContext *context)
-{
-/* Camera *camera;*/
-
-	/*
-	 * Upload the file to the camera. Use gp_file_get_data_and_size,
-	 * gp_file_get_name, etc.
-	 */
-
-	return (GP_OK);
-}
-
 static int
 delete_file_func (CameraFilesystem *fs, const char *folder,
 		  const char *filename, void *data, GPContext *context)
@@ -281,7 +264,7 @@ camera_about (Camera *camera, CameraText *about, GPContext *ctx)
 	strcpy (about->text, _("Mustek MDC-800 gPhoto2 Library\n"
 			       "Henning Zabel <henning@uni-paderborn.de>\n"
 			       "Ported to gphoto2 by Marcus Meissner <marcus@jet.franken.de>\n"
-			       "Supports Serial and USB Protocol."));
+			       "Supports Serial and USB Protocols."));
 	return (GP_OK);
 }
 
@@ -321,6 +304,15 @@ file_list_func (CameraFilesystem *fs, const char *folder, CameraList *list,
 	return (GP_OK);
 }
 
+static CameraFilesystemFuncs fsfuncs = {
+	.file_list_func = file_list_func,
+	.folder_list_func = folder_list_func,
+	.get_file_func = get_file_func,
+	.get_info_func = get_info_func,
+	.del_file_func = delete_file_func,
+	.delete_all_func = delete_all_func
+};
+
 int
 camera_init (Camera *camera, GPContext *context)
 {
@@ -334,14 +326,7 @@ camera_init (Camera *camera, GPContext *context)
         camera->functions->about                = camera_about;
 
 	/* Now, tell the filesystem where to get lists, files and info */
-	gp_filesystem_set_list_funcs (camera->fs, file_list_func,
-				      folder_list_func, camera);
-	gp_filesystem_set_info_funcs (camera->fs, get_info_func, NULL,
-				      camera);
-	gp_filesystem_set_file_funcs (camera->fs, get_file_func,
-				      delete_file_func, camera);
-	gp_filesystem_set_folder_funcs (camera->fs, put_file_func,
-					delete_all_func, NULL, NULL, camera);
+	gp_filesystem_set_funcs (camera->fs, &fsfuncs, camera);
 
 	/* Configure port */
 	gp_port_set_timeout(camera->port,MDC800_DEFAULT_COMMAND_RETRY_DELAY);
