@@ -57,6 +57,7 @@ int
 camera_abilities (CameraAbilitiesList *list)
 {
 	CameraAbilities a;
+	int ret;
 
 	memset (&a, 0, sizeof(a));
 	strcpy (a.model, "Pentax:K20D");
@@ -68,7 +69,29 @@ camera_abilities (CameraAbilitiesList *list)
 	a.operations 		= GP_OPERATION_CAPTURE_IMAGE | GP_OPERATION_CONFIG;
 	a.folder_operations	= GP_FOLDER_OPERATION_NONE;
 	a.file_operations	= GP_FILE_OPERATION_DELETE;
-	return gp_abilities_list_append (list, a);
+	if (GP_OK != (ret = gp_abilities_list_append (list, a)))
+		return ret;
+	strcpy (a.model, "Pentax:K10D");
+	a.usb_product		= 0x006e;
+	if (GP_OK != (ret = gp_abilities_list_append (list, a)))
+		return ret;
+	strcpy (a.model, "Pentax:K100D");
+	a.usb_product		= 0x0070;
+	if (GP_OK != (ret = gp_abilities_list_append (list, a)))
+		return ret;
+
+	strcpy (a.model, "Pentax:K200D");
+	a.usb_product		= 0x0093;
+	if (GP_OK != (ret = gp_abilities_list_append (list, a)))
+		return ret;
+
+	/* weird usb vendor? */
+	strcpy (a.model, "Pentax:K5D");
+	a.usb_vendor		= 0x25fb;
+	a.usb_product		= 0x0102;
+	if (GP_OK != (ret = gp_abilities_list_append (list, a)))
+		return ret;
+	return GP_OK;
 }
 
 static int
@@ -76,7 +99,7 @@ camera_summary (Camera *camera, CameraText *summary, GPContext *context)
 {
 	sprintf (summary->text, _(
 		"Pentax K DSLR capture driver.\n"
-		"Based in pkremote by Pontus Lidman.\n"
+		"Based on pkremote by Pontus Lidman.\n"
 	));
 	return GP_OK;
 }
@@ -118,7 +141,7 @@ save_buffer(pslr_handle_t camhandle, int bufno, CameraFile *file, pslr_status *s
 {
 	int imagetype;
 	uint8_t buf[65536];
-	uint32_t length;
+	int length;
 	uint32_t current;
 
 	if (status->image_format != PSLR_IMAGE_FORMAT_JPEG) {
