@@ -22,23 +22,23 @@
 #ifndef __PTP_BUGS_H_
 #define __PTP_BUGS_H_
 
+#include "device-flags.h"
 
-#define PTPBUG_DELETE_SENDS_EVENT	(1<<1)
-#define PTPBUG_DUPE_FILE		(1<<2)
-#define PTP_MTP				(1<<3)
-#define PTP_CAP				(1<<4)
-#define PTP_CAP_PREVIEW			(1<<5)
-#define PTP_MTP_PROPLIST_WORKS		(1<<6)
-#define PTP_NIKON_BROKEN_CAP		(1<<7)
-#define PTP_MTP_ZEN_BROKEN_HEADER	(1<<8)
+#define PTPBUG_DELETE_SENDS_EVENT	DEVICE_FLAG_DELETE_SENDS_EVENT
+#define PTP_CAP				DEVICE_FLAG_CAPTURE
+#define PTP_CAP_PREVIEW			DEVICE_FLAG_CAPTURE_PREVIEW
+#define PTP_NIKON_BROKEN_CAP		DEVICE_FLAG_NIKON_BROKEN_CAPTURE
+#define PTP_MTP_ZEN_BROKEN_HEADER	DEVICE_FLAG_IGNORE_HEADER_ERRORS
+#define PTP_NO_CAPTURE_COMPLETE		DEVICE_FLAG_NO_CAPTURE_COMPLETE
+#define PTP_MATCH_IFACE_DIRECTLY	DEVICE_FLAG_MATCH_PTP_INTERFACE
 
 #define DELETE_SENDS_EVENT(x) \
-  ((x)->bugs & PTPBUG_DELETE_SENDS_EVENT)
-#define CAN_HAVE_DUPE_FILE(x) \
-  ((x)->bugs & (PTPBUG_DUPE_FILE | PTP_MTP))
+  ((x)->device_flags & (DEVICE_FLAG_DELETE_SENDS_EVENT))
 #define NIKON_BROKEN_CAP(x) \
-  ((x)->bugs & (PTP_NIKON_BROKEN_CAP))
+  ((x)->device_flags & (DEVICE_FLAG_NIKON_BROKEN_CAPTURE))
+#define NO_CAPTURE_COMPLETE(x) \
+  ((x)->device_flags & (DEVICE_FLAG_NO_CAPTURE_COMPLETE))
 #define MTP_ZEN_BROKEN_HEADER(x) \
-  ((x)->bugs & (PTP_MTP_ZEN_BROKEN_HEADER))
+  ((x)->device_flags & (DEVICE_FLAG_IGNORE_HEADER_ERRORS))
 
 #endif
