@@ -536,11 +536,11 @@ sierra_read_packet (Camera *camera, unsigned char *packet, GPContext *context)
 	}
 
 	/* Try several times before leaving on error... */
-	/* Clear the USB bus
-	   (what about the SERIAL bus : do we need to flush it?) */
-	sierra_clear_usb_halt(camera);
 	while (1) {
 
+		/* Clear the USB bus
+		   (what about the SERIAL bus : do we need to flush it?) */
+		sierra_clear_usb_halt(camera);
 
 		/*
 		 * Read data through the bus. If an error occurred,
@@ -759,6 +759,7 @@ sierra_transmit_ack (Camera *camera, char *packet, GPContext *context)
 
 		/* Write packet and read the answer */
 		CHECK (sierra_write_packet (camera, packet, context));
+		buf[0] = 0;
 		result = sierra_read_packet_wait (camera, buf, context);
 		switch (result) {
 		case GP_ERROR_CORRUPTED_DATA:
@@ -1010,7 +1011,8 @@ int sierra_sub_action (Camera *camera, SierraAction action, int sub_action,
 	CHECK (sierra_read_packet_wait (camera, buf, context));
 
 	switch (buf[0]) {
-		case SIERRA_PACKET_ENQ:
+	case ACK: /* reported on capture on Olympus 4040 */
+	case SIERRA_PACKET_ENQ:
 		return (GP_OK);
 	default:
 		gp_context_error (context, _("Received unexpected answer "
@@ -1070,6 +1072,7 @@ int sierra_get_int_register (Camera *camera, int reg, int *value, GPContext *con
 	while (1) {
 
 		/* Read the response */
+		buf[0] = 0;
 		CHECK (sierra_read_packet_wait (camera, buf, context));
 		GP_DEBUG ("Successfully read packet. Interpreting result "
 			  "(0x%02x)", buf[0]);
@@ -1206,7 +1209,6 @@ int sierra_get_string_register (Camera *camera, int reg, int fnumber,
 	int retries, r;
 	unsigned int min_progress_bytes;
 	static int in_function = 0;
-	const char *file_name;
 	unsigned int id = 0;
 
 	GP_DEBUG ("sierra_get_string_register:  reg %i, file number %i, "
@@ -1243,7 +1245,6 @@ int sierra_get_string_register (Camera *camera, int reg, int fnumber,
 	CHECK (sierra_write_packet (camera, p, context));
 
 	if (file && total > min_progress_bytes) {
-		CHECK (gp_file_get_name(file, &file_name));
 		id = gp_context_progress_start (context, total, _("Downloading data..."));
 	}
 
